[![PyPI version](https://badge.fury.io/py/yroom.svg)](https://badge.fury.io/py/yroom)

# Yroom

Python API to synchronize clients and distribute updates via the Yjs protocol. It's written in Rust and uses [Yrs](https://github.com/y-crdt/y-crdt) and [y-sync](https://github.com/y-crdt/y-sync).

It was built for [channels-yroom](https://github.com/stefanw/channels-yroom).

## Installation

```
pip install yroom
```

## API

See `yroom.pyi`.
